@@ -3,15 +3,21 @@
 from PyQt4 import QtCore, QtGui
 from qtGUI.MainWindow import ImproviserMainWindow
 from qtGUI.PreferencesDialog import PreferencesDialog
+from FileCollection import FileCollection
 from sys import argv
 
 def show_main(params):
 	i = ImproviserMainWindow()
 	i.loggedin = params["login"]
 	i.default_folder = params["default_folder"]
-	i.checkupdates = params["checkupdates"]
+
 	i.credentials = {"username": params["username"], 
 			 "password": params["password"]}
+	fc = FileCollection(i.default_folder)
+	fc.credentials = i.credentials
+	fc.loggedin = i.loggedin
+	fc.checkupdates = params["checkupdates"]
+	i.filecollection = fc
 
 	if 'soundfont' not in params:
 		i.no_fluidsynth = True
